#!/usr/bin/env python3
from flask import Flask, render_template, url_for, request

app = Flask("blogg")

data = blog_entries = [
    {
        "title": "Introduction to Python Programming",
        "author": "John Smith",
        "date": "2023-01-15",
        "content": "In this blog post, we'll explore the basics of Python programming, including data types, variables, and control structures.",
    },
    {
        "title": "The Art of Data Visualization",
        "author": "Alice Johnson",
        "date": "2023-02-10",
        "content": "Learn how to create stunning data visualizations using popular Python libraries like Matplotlib and Seaborn.",
    },
    {
        "title": "Machine Learning Fundamentals",
        "author": "David Williams",
        "date": "2023-03-20",
        "content": "Discover the core concepts of machine learning, from supervised to unsupervised learning, and get started with scikit-learn.",
    },
    {
        "title": "The Future of Artificial Intelligence",
        "author": "Sophia Lee",
        "date": "2023-04-18",
        "content": "Explore the exciting possibilities and potential ethical challenges of artificial intelligence in this thought-provoking blog post.",
    },
    {
        "title": "Web Development with Django",
        "author": "Michael Brown",
        "date": "2023-05-25",
        "content": "Get a step-by-step guide on building web applications using the Django framework, including database integration and authentication.",
    },
]


@app.route("/")
def index():
    return render_template("index.html")


@app.route("/search")
def search():
    searchterm = request.args.get("searchterm")
    matches = []
    for d in data:
        if searchterm in d["content"]:
            matches.append(d)
    if matches:  # if the matches list is not empty
        return render_template("posts.html", entries_to_render=matches)
    else:
        return render_template("index.html")


@app.route("/posts")
def posts():
    return render_template("posts.html", entries_to_render=data)


@app.route("/post/<title>")
def post(title):
    entry = {}
    for d in data:
        if d["title"] == title:
            entry = d
    return render_template("post.html", entry_to_render=entry)


if __name__ == "__main__":
    app.run(debug=True)
